package controllers

import (
	"encoding/json"
	"fmt"
	"hongze/hongze_robot/cache"
	"hongze/hongze_robot/models"
	"hongze/hongze_robot/services"
	"hongze/hongze_robot/utils"
	"strconv"
	"strings"
	"time"
)

//短信管理
type SmsController struct {
	BaseCommonController
}

// @Title 短信转发接口
// @Description 短信转发接口
// @Param	request	body company.CompanyApplyApproveReq true "type json string"
// @Success Ret=200 转发成功
// @router /send [post]
func (this *SmsController) SmsSend() {
	br := new(models.BaseResponse).Init()
	var err error
	defer func() {
		if err != nil {
			utils.FileLog.Info("send msg err: %s", err.Error())
		}
		this.Data["json"] = br
		this.ServeJSON()
	}()
	reqBody := this.Ctx.Input.RequestBody
	utils.FileLog.Info("%s", string(reqBody))
	req := make([]*models.SmsReq, 0)
	err = json.Unmarshal(reqBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}

	addList := make([]*models.SmsRecord, 0)
	for _, v := range req {
		v.Address = strings.Trim(v.Address, " ")
		if v.Sign != utils.Sign {
			br.Msg = "签名错误"
			br.ErrMsg = "签名错误；get sign：" + v.Sign + ";check sign:" + utils.Sign
			return
		}
		unionCode := utils.MD5(v.Address + v.Body + v.Date)
		count, err := models.GetSmsRecordCount(unionCode)
		if err != nil && err.Error() != utils.ErrNoRow() {
			br.Msg = "失败，请联系技术"
			br.ErrMsg = "失败；Err:" + err.Error()
			return
		}
		fmt.Println("count:", count)
		item, err := cache.GetSmsConfigByCache("mobile")
		if err != nil {
			br.Msg = "失败，请联系技术"
			br.ErrMsg = "获取配置信息失败；Err:" + err.Error()
			return
		}
		if item.ConfigValue == "" {
			br.Msg = "失败，请联系技术"
			br.ErrMsg = "配置信息为空"
			return
		}
		fmt.Println(item.ConfigValue)
		fmt.Println(v.Address)
		fmt.Println(strings.Contains(item.ConfigValue, v.Address))
		//判断记录是否存在
		if count <= 0 && strings.Contains(item.ConfigValue, v.Address) {
			var tm time.Time
			if v.Date != "" {
				smsDateInt64, _ := strconv.ParseInt(v.Date, 10, 64)
				tm = time.Unix(smsDateInt64/1e3, 0)
			}
			record := new(models.SmsRecord)
			record.CreateTime = time.Now()
			record.ModifyTime = time.Now()
			record.IsSend = 0
			record.SmsDateTime = tm
			record.Mobile = v.Address
			record.SmsDate = v.Date
			record.Body = v.Body
			record.UnionCode = unionCode
			addList = append(addList, record)
		}
	}
	if len(addList) > 0 {
		_, err = models.AddSmsRecordMulti(addList)
		if err != nil {
			br.Msg = "失败，请联系技术"
			br.ErrMsg = "新增记录失败；Err:" + err.Error()
			return
		}
		time.Sleep(1 * time.Second)
		go services.SendSms()
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "发送成功"
}

//func init() {
//	fmt.Println("start")
//	smsDate:=`1620290685894`
//	int64, err := strconv.ParseInt(smsDate, 10, 64)
//	fmt.Println(err)
//	tm:=time.Unix(int64/1e3,0)
//	fmt.Println(tm)
//	fmt.Println(tm.Format(utils.FormatDateTime))
//	fmt.Println("end")
//}

//func init() {
//	fmt.Println("start")
//	services.SendSms()
//	fmt.Println("end")
//	return
//}